<?php /* /momo/lib/lib_ui.php, (c) 2006, Andreas Forstinger, www.mobilemoodle.org */
// this library provides GUI related helper functions

//// ##########################################################################
////  Output and Formatting related functions
//// ##########################################################################


/**
 * This function returns the localized string for the given identifier. It internally uses
 * the moodle function "print_string" but automatically sets the module identifier to "momo"
 */
function momo_print_string($identifier, $mixed = NULL) {
    return print_string($identifier, 'momo', $mixed);
}

/**
 * This function returns the localized string for the given identifier. It internally uses
 * the moodle function "print_string" but automatically sets the module identifier to "momo"
 */
function momo_get_string($identifier, $mixed = NULL) {
    return get_string($identifier, 'momo', $mixed);
}

/**
 * This function converts the given markup text to MLE compatible format
 * @return converted text
 */
function momo_get_converted_text($text,$showinlineimages=false) {

    global $CFG;

    // replace img tags with corresponding MLE compatible image tag
    // based on http://www.webmasterworld.com/forum88/1395.htm
    $imgpattern = "/\<\s*img\s*[^\>\/]*src\s*=\s*[\"\']{0,1}([^\"\'\s]*)[\"\']{0,1}[^\>\/]*[\/]?\>/e";

    if($showinlineimages){
        $imgreplace = "'<image type=\"h\" url=\"' . momo_encode_login_information('$1') . '\" />'";
    }
    else{
        $imgreplace = "'<image type=\"r\" url=\"' . momo_encode_login_information('$1') . '\" />'";
    }

    $nutext = preg_replace($imgpattern,$imgreplace,$text);

    // correct relative image paths ("../file.php") to absolute
    $nutext = str_replace('../file.php', $CFG->wwwroot . '/file.php', $nutext);

    // correct spaces
    $nutext = str_replace('&nbsp;',' ',$nutext);

    // do linebreaks
    $nutext = preg_replace("/\\r\\n|\\n|\\r|<\/p>|<\/P>|<br \/>/",'<br/>',$nutext);

    // remove all tags left that are not compatible with MLE ML
    $nutext = strip_tags($nutext,$CFG->momo_compatible_tags);

    return $nutext;
}

/**
 * This function prints the given text correctly formatted for MOMO
 */
function momo_print_converted_text($text,$showinlineimages=false) {
    echo momo_get_converted_text($text, $showinlineimages);
}

/**
 * This function truncates the given string to fit into specified $max_size
 * [This function was originally taken from block_course_menu/XTree]
 * @param $string: string to truncate
 * @param $max_size: length of largest piece when done
 * @param $trunc: string to append to truncated pieces ('...')
 *
 */
function momo_truncate($string, $max_size=25, $trunc = '...') {
    $split_tags = array('<br>','<BR>','<Br>','<bR>','</dt>','</dT>','</Dt>','</DT>','</p>','</P>', '<BR />', '<br />', '<bR />', '<Br />');
    $temp = $string;

    foreach($split_tags as $tag) {
        list($temp) = explode($tag, $temp, 2);
    }
    $rstring = strip_tags($temp);

    $rstring = html_entity_decode($rstring);

    if (strlen($rstring) > $max_size) {
        $rstring = chunk_split($rstring, ($max_size-strlen($trunc)), "\n");
        $temp = explode("\n", $rstring);
        // catches new lines at the beginning
        if (trim($temp[0]) != '') {
            $rstring = trim($temp[0]).$trunc;
        }
        else {
           $rstring = trim($temp[1]).$trunc;
        }
    }
    if (strlen($rstring) > $max_size) {
        $rstring = substr($rstring, 0, ($max_size - strlen($trunc))).$trunc;
    }
    elseif($rstring == '') {
        // we chopped everything off... lets fall back to a failsafe but harsher truncation
        $rstring = substr(trim(strip_tags($string)),0,($max_size - strlen($trunc))).$trunc;
    }

    // single quotes need escaping
    return str_replace("'", "\\'", $rstring);
}

/**
 * This function prints the necessary elements for paging (page wrap)
 */
function momo_print_paging() {
?>
<br align="center"/><font class="h3"/><?php momo_print_string('nav_paging')?></page><page><br align="center"/><font class="h3"/><?php momo_print_string('nav_paging_continued')?><font class="std"/><br align="left"/>
<?php
}


/**
 * This function returns the appropriate "back" link
 * @param integer $courseid optional the id of the current course
 */
function momo_get_back_url($courseid = null){

    global $CFG;

    // define default link
    $url = 'index.xml';

    // get referer string the client sends (format: <linktype>|<linkurl>#page
    $referer = momo_basic_get_header($CFG->momo_mle_param_referer,null);

    if(!empty($referer)){ // when Gateway server is not used, referer is not set!!
        $tokens = explode ('|', $referer);
        $url = (count($tokens) > 2) ? $tokens[2] : $tokens[1];

        // "&" has to be escaped
        $url = str_replace('&', '&amp;', $url);
    }
    else{ // no gateway in use

        if(!empty($courseid)){

            // special case if the current course is the "Moodle Community" course
            if ($courseid == $CFG->momo_community_course) {
                $url = 'com/mobile_community.php|m';
            }
            else {
                $url = "course/course.php&amp;id=$courseid|m";
            }
        }

    }

    return $url;

}

/**
 * This function prints the required image tag that displays the given user image
 * @param $userid id of user
 * @param $fullsize: true shows the full size image (100x100 pixel), otherwise the small
 * images (35x35 pixel) is displayed
 *
 */
function momo_print_user_picture($userid, $fullsize = false){
    global $CFG;
    $file = ($fullsize) ? 'f1.jpg' : 'f2.jpg';
    echo '<image type="' . $CFG->momo_mle_server_link . '" url="user&amp;id=' . $userid . '&amp;file=' . $file . '" />';
}


/**
 * This function prints a page header with the given icon (as defined in properties.php) and title
 * @param $title title to be shown in header;
 * @param $icon icon as defined in properties.php; if not specified a default icon is displayed
 */
function momo_print_header($title, $icon = ''){
    if(empty($icon)){
        $icon = 'internet';
    }
?>
<image type="l" url="<?php momo_print_icon_path($icon)?>"> <font class="h2"/><?php p(momo_truncate($title,15)) ?><font class="std"/><br/><hr/>
<?php
}

/**
 * This function prints the given text formatted as notice
 * (i.e. "no results" or "no entries"
 */
function momo_print_notice($notice=''){
?>
<br align="center"/><font style="i"/><?php p($notice)?><font style="p"/><br align="left"/>
<?php
}


/**
 * This function prints a success screen
 */
function momo_print_success($message='', $backurl='index.xml', $backurltype='y'){
?>
<ps t="<?php momo_print_string('hd_success') ?>" s="false" bo="false" back="<?php echo($backurl . '|' . $backurltype) ?>">
<pa>
<image type="l" url="<?php momo_print_icon_path('ok')?>" /> <font class="h2"/><?php momo_print_string('hd_success') ?><font class="std"/>
<br align="center"/><hr/>
<font class="h3"/>
<?php p($message) ?>
<font class="std" />
</pa>
</ps>
<?php
// flush the page
momo_flushXMLToClient();
}

/**
 * This function prints an error screen
 */
function momo_print_error($message='', $backurl='index.xml', $backurltype='y'){
?>
<ps t="<?php momo_print_string('hd_error') ?>" s="false" bo="false" back="<?php echo($backurl . '|' . $backurltype) ?>">
<pa>
<image type="l" url="<?php momo_print_icon_path('error')?>" /><font class="h2"/> <?php momo_print_string('hd_error') ?><font class="std"/>
<br align="center"/><hr/>
<font class="h3"/>
<?php momo_print_string($message) ?>
<font class="std" />
</pa>
</ps>
<?php
// flush the page
momo_flushXMLToClient();
}
?>